@@ -1,5 +1,5 @@
 // -*- c++ -*-
-/* $Id: ustring.cc 441 2007-09-03 00:30:54Z daniel $ */
+/* $Id: ustring.cc 722 2008-08-27 09:49:45Z arminb $ */
 
 /* Copyright (C) 2002 The gtkmm Development Team
  *
@@ -28,7 +28,10 @@
 #include <iostream>
 #include <cstring>
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
+
 #include <glibmmconfig.h>
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
 # include <stdexcept>
@@ -683,7 +686,10 @@ ustring& ustring::erase()
 
 ustring::iterator ustring::erase(ustring::iterator p)
 {
-  return iterator(string_.erase(p.base()));
+  ustring::iterator iter_end = p;
+  ++iter_end;
+
+  return iterator(string_.erase(p.base(), iter_end.base()));
 }
 
 ustring::iterator ustring::erase(ustring::iterator pbegin, ustring::iterator pend)
